@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -6,7 +5,7 @@
 
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license
-# Copyright (c) 2011 globo.com timehome@corp.globo.com
+# Copyright (c) 2011 globo.com <thumbor@g.globo>
 
 from remotecv.detectors import CascadeLoaderDetector
 
@@ -22,7 +21,7 @@ class FaceDetector(CascadeLoaderDetector):
         return top
 
     def detect(self, image):
-        features = self.get_features(image)
+        features = self.get_grayscale_equalized_features(image)
         points = []
         if features:
             for (left, top, width, height), _neighbors in features:
