@@ -16,8 +16,9 @@ from importlib import import_module
 from threading import Thread
 
 from remotecv.error_handler import ErrorHandler
-from remotecv.utils import config, redis_client, SINGLE_NODE, SENTINEL
 from remotecv.healthcheck import HealthCheckHandler
+from remotecv.importer import Importer
+from remotecv.utils import config, redis_client, SINGLE_NODE, SENTINEL, context
 
 
 def start_pyres_worker():
@@ -31,7 +32,10 @@ def start_pyres_worker():
         config.error_handler.install_handler()
 
     worker = UniqueWorker(
-        queues=["Detect"], server=redis, timeout=config.timeout, after_fork=after_fork
+        queues=["Detect"],
+        server=redis,
+        timeout=config.timeout,
+        after_fork=after_fork,
     )
     worker.work()
 
@@ -63,6 +67,12 @@ def start_http_server():
     thread.start()
 
 
+def import_modules():
+    Metrics = Importer.import_class("Metrics", config.metrics)
+    context.metrics = Metrics(config)
+    context.metrics.initialize()
+
+
 def main(params=None):
     if params is None:
         params = sys.argv[1:]
@@ -79,8 +89,12 @@ def main(params=None):
 
     conn_group = parser.add_argument_group("Pyres Connection Arguments")
     conn_group.add_argument("--host", default="localhost", help="Redis host")
-    conn_group.add_argument("--port", default=6379, type=int, help="Redis port")
-    conn_group.add_argument("--database", default=0, type=int, help="Redis database")
+    conn_group.add_argument(
+        "--port", default=6379, type=int, help="Redis port"
+    )
+    conn_group.add_argument(
+        "--database", default=0, type=int, help="Redis database"
+    )
     conn_group.add_argument("--password", default=None, help="Redis password")
     conn_group.add_argument(
         "--redis-mode",
@@ -97,10 +111,14 @@ def main(params=None):
         "--sentinel-password", default=None, help="Redis Sentinel password"
     )
     conn_group.add_argument(
-        "--master-instance", default=None, help="Redis Sentinel master instance"
+        "--master-instance",
+        default=None,
+        help="Redis Sentinel master instance",
     )
     conn_group.add_argument(
-        "--master-password", default=None, help="Redis Sentinel master password"
+        "--master-password",
+        default=None,
+        help="Redis Sentinel master password",
     )
     conn_group.add_argument(
         "--master-database",
@@ -116,9 +134,13 @@ def main(params=None):
     )
 
     conn_group = parser.add_argument_group("Celery/SQS Connection Arguments")
-    conn_group.add_argument("--region", default="us-east-1", help="AWS SQS Region")
+    conn_group.add_argument(
+        "--region", default="us-east-1", help="AWS SQS Region"
+    )
     conn_group.add_argument("--key_id", default="", help="AWS access key id")
-    conn_group.add_argument("--key_secret", default="", help="AWS access key secret")
+    conn_group.add_argument(
+        "--key_secret", default="", help="AWS access key secret"
+    )
     conn_group.add_argument(
         "--polling_interval", default=20, help="AWS polling interval"
     )
@@ -130,15 +152,20 @@ def main(params=None):
     other_group.add_argument(
         "--with-healthcheck",
         default=False,
-        action='store_true',
+        action="store_true",
         help="Start an healthchecker http endpoint",
     )
-    other_group.add_argument("-l", "--level", default="debug", help="Logging level")
+    other_group.add_argument(
+        "-l", "--level", default="debug", help="Logging level"
+    )
     other_group.add_argument(
         "-o", "--loader", default="remotecv.http_loader", help="Loader used"
     )
     other_group.add_argument(
-        "-s", "--store", default="remotecv.result_store.redis_store", help="Loader used"
+        "-s",
+        "--store",
+        default="remotecv.result_store.redis_store",
+        help="Loader used",
     )
     other_group.add_argument(
         "-t",
@@ -150,8 +177,15 @@ def main(params=None):
     other_group.add_argument(
         "--sentry_url", default=None, help="URL used to send errors to sentry"
     )
+    other_group.add_argument(
+        "--metrics",
+        default="remotecv.metrics.logger_metrics",
+        help="Metrics client, should be the full name of a python module",
+    )
 
-    memcache_store_group = parser.add_argument_group("Memcache store arguments")
+    memcache_store_group = parser.add_argument_group(
+        "Memcache store arguments"
+    )
     memcache_store_group.add_argument(
         "--memcache_hosts",
         default="localhost:11211",
@@ -186,6 +220,7 @@ def main(params=None):
     config.log_level = arguments.level.upper()
     config.loader = import_module(arguments.loader)
     config.store = import_module(arguments.store)
+    config.metrics = arguments.metrics
 
     config.memcache_hosts = arguments.memcache_hosts
 
@@ -193,6 +228,8 @@ def main(params=None):
 
     config.error_handler = ErrorHandler(arguments.sentry_url)
 
+    import_modules()
+
     if arguments.with_healthcheck:
         start_http_server()
 
